..
    Copyright (C) 2021 Graz University of Technology.

    invenio-campusonline is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

======================
 invenio-campusonline
======================

.. image:: https://github.com/tu-graz-library/invenio-campusonline/workflows/CI/badge.svg
        :target: https://github.com/tu-graz-library/invenio-campusonline/actions?query=workflow%3ACI

.. image:: https://img.shields.io/github/tag/tu-graz-library/invenio-campusonline.svg
        :target: https://github.com/tu-graz-library/invenio-campusonline/releases

.. image:: https://img.shields.io/pypi/dm/invenio-campusonline.svg
        :target: https://pypi.python.org/pypi/invenio-campusonline

.. image:: https://img.shields.io/github/license/tu-graz-library/invenio-campusonline.svg
        :target: https://github.com/tu-graz-library/invenio-campusonline/blob/master/LICENSE

This module is used to import/export from/to the CampusOnline System.

TODO: Please provide feature overview of module

Further documentation is available on
https://invenio-campusonline.readthedocs.io/
